ren scene_new(name: "");
ren scene_pos(pos: x, y, z);
ren scene_scale(scale: x, y, z);
ren scene_rotate(rotate: x, y, z);
ren scene_add_object(object: "");
loc camera_new(pos: x, y, z, look_at: x, y, z);
loc camera_pos(pos: x, y, z);
loc camera_look_at(look_at: x, y, z);
fov camera = (exist: "") by;
ren render(start);
ren render(stop);
print(ren);
print(fov);
let cossion "";
let object move in(x, y, z);
wait(seconds: "") in(scene: "");
see ren on(scene: "");
physical if(object_if);
physical then(do: "");
physical prompt("", do: "");
up in(y);
down in(y);
left in(x);
right in(x);
back in(z);
front in(z);
complex object(object: "") with(object: "");
loop in(scene: "") time(seconds: "");
end loop;
start loop;
get loop(id: "");
this loop(id: "");
if(true?);
if(false?);
frontKid in(z: "");
backKid in(z: "");
loopKid in(scene: "");
endKid();
camera point(x, y, z);
direction (x);
distance (x);
direction (y);
distance (y);
direction (z);
distance (z);
loot in(scene: "") otherwise(set: "", scene: "");
pant local(script: "") works on(scene: "");
graphic model(model: "") works on(scene: "");
graphic_model = "";
load graphic_model(model: "");
load graphic_model(model: "") works on(scene: "");
load graphic_model(model: "") works on(scene: "") otherwise(set: "", scene: "");
print(graphic_model: "");
print(graphic_model: "") works on(scene: "");
print(graphic_model: "") works on(scene: "") otherwise(set: "", scene: "");
print(ren on(scene: ""));
print(ren on(scene: "")) otherwise(set: "", scene: "");
sins entity(entity: "");
ren_entity = "";
load ren_entity(entity: "");
load ren_entity(entity: "") works on(scene: "");
load ren_entity(entity: "") works on(scene: "") otherwise(set: "", scene: "");
print(ren_entity: "");
print(ren_entity: "") works on(scene: "");
print(ren_entity: "") works on(scene: "") otherwise(set: "", scene: "");
polish?(true);
polish?(false);
complete ren(){
    render:ren comp(TRUE);
}
